      SUBROUTINE EIGEN
*
* finds the eigenvalue and eigenfunction of a particle with charge Z1,
* in a WS + Coulomb + spin-orbit potential with a nucleus with charge Z2.
*
*   input parameters
*   ================
* 
* IOPT   = option for potentials: 1 (2) for Woods-Saxon (M3Y)
* NPNTS  = number of points in the radial mesh
* RMAX   = maximum radius size
* N_0    = nodes of the wave function 
* L0     = orbital angular momentum of single particle state
* J0     = total angular momentum of single particle state 
* V0     = depth of central potential 
* VS0    = depth of spin-orbit potential 
* R0     = radius of the central potential
* RC     = radius of Coulomb potential 
* RS0    = radius of the spin-orbit potential
* AAS    = diffuseness of the spin-orbit potential 
* If IOPT >= 2, then enter FC and FSO: 
* FC     = multiplicative factor of central part of M3Y potential
* FSO    = multiplicat. factor of spin-orbit part of M3Y potential
* Z1, Z2 = charges of the nuclei
* A1, A2 = masses of the nuclei (in nucleon mass units) 
*
      IMPLICIT REAL*8 (A-H,O-Z)
*
      PARAMETER(NLG=10000)
*
      REAL*8 R(0:NLG),UM3Y(0:NLG),VN1(0:NLG),VN2(0:NLG)
      COMMON /POTENTIAL/ U(NLG),WSO(NLG),UE(NLG)
     &                   ,VC(NLG)
      COMMON /M3Y/ FC,FSO,UM3Y,VN1
      COMMON /WAVE_FUNCTIONS/ EIGWF(NLG)
      COMMON /PAR/  DR,DR2,PI,FOUR_PI,NPNTS
      COMMON /POT/ V0,VS0,R0,RS0,RC,AA,AAS,Z1Z2,ARED
*
      OPEN(UNIT=12,FILE='EIGEN.INP', STATUS='UNKNOWN')
      OPEN(UNIT=16,FILE='GSWF.INP', STATUS='UNKNOWN')
      OPEN(UNIT=13,FILE='EIGEN.TXT', STATUS='UNKNOWN')
*
      WRITE(6,*)' '
      WRITE(13,*)'** Bound-state in cent. + Coul. + spin-orbit pot **'
      WRITE(13,*)' '
*
* mesh size, no. of points in the radial mesh, max. radius size
      CALL SKIPCOM(12)
      READ(12,*) IOPT,NPNTS,RMAX
*
* check if we are out of bounds
      IF(NPNTS.GT.NLG .OR. RMAX.GT.250. OR. 
     &       	NPNTS.LT.100 .OR. RMAX.LT.50.) THEN
        WRITE(6,*)'THE INPUT VALUES FOR NPNTS OR RMAX ARE INADEQUATE'
        WRITE(6,*)' 100 <= NPNTS <= 10000,    50 <= RMAX <= 250'
        STOP
      ENDIF
*
      DR=RMAX/NPNTS
*
* nodes of the wave function, total angular momentum, orbital ang. mom.
      CALL SKIPCOM(12)
      READ(12,*) N_0,AJ0,L0
*
* potential parameters  
      FC=0.
      CALL SKIPCOM(12)
      IF(IOPT.EQ.1) THEN
        READ(12,*)V0,R0,AA,VS0,RS0,AAS,RC
       ELSE
        READ(12,*)FC,FSO,RC      
        DO I=0,NPNTS
          R(I)=I*DR
        ENDDO 
        CALL OMP_READ(R,DR,NPNTS,UM3Y)
        CALL DERIVATIVE(UM3Y,VN1,VN2,DR,NPNTS)             		 
      ENDIF        
*
* masses and charges
      CALL SKIPCOM(12)
      READ(12,*)Z1,A1,Z2,A2
*
      CLOSE(UNIT=12)
*
      WRITE(13,*)'Potential parameters'
      IF(IOPT.EQ.1) THEN
        WRITE(13,*)' V0            R0          AA'
        WRITE(13,20)V0,R0,AA
        WRITE(13,*)' VS0           RS0         AAS          RC'
        WRITE(13,21)VS0,RS0,AAS,RC
       ELSE
        WRITE(13,*)' FC            FSO          RC'
        WRITE(13,20)FC,FSO,RC
      ENDIF
*
      WRITE(13,*)'Charges and masses'
      WRITE(13,*)'Z1     A1     Z2     A2'  
      WRITE(13,22)int(Z1),int(A1),int(Z2),int(A2)
20    FORMAT(3(F8.3,4X),/)
21    FORMAT(4(F8.3,4X),/)
22    FORMAT(4(I2,5X),/)
*
      Z1Z2=Z1*Z2
      ARED=A1*A2/(A1+A2)
*
      WRITE(13,*)'Radial integration parameters'
      WRITE(13,*) 'NPNTS      RMAX (fm)'
      WRITE(13,8) NPNTS,RMAX
8     FORMAT(I6,4X,F8.1,/)
*
* famous constants
      PI = 3.14159265359
      FOUR_PI = 4.0D0 *PI
*
* Setup nuclear + Coulomb + spin-orbit potential
      CALL POTENT
*
* Integrate Schroedinger equation
      CALL BOUNDWAVE(N_0,L0,AJ0,ENER)
*
* Output
      WRITE(6,*)' '
      WRITE(6,*)'N_0     L0     AJ0     Energy  (MeV)'
      WRITE(6,104) N_0,L0,AJ0,ENER
      WRITE(13,*)'N_0     L0      AJ0     Energy  (MeV)'
      WRITE(13,104) N_0,L0,AJ0,ENER
 104  FORMAT(2(I2,6X),F4.1,6X,F6.2,/)
      WRITE(13,*)'    R (fm)    x     Wavefunction'
      WRITE(13,*)' '
*
      WRITE(16,*)NPNTS
      DO IR=1,NPNTS
        XR=IR*DR        
        WRITE(13,*)XR,EIGWF(IR)
        WRITE(16,*)XR,EIGWF(IR)
      ENDDO
*
      PRINT*,' '
	PRINT*,'- Output of r x wavefunction in EIGEN.TXT and GSWF.INP'
	PRINT*,'- GSWF.INP is prepared for use as input wavefunct to'
      PRINT*,'  subroutine BVALUE (reduced transition probabilities)'
      PRINT*,'  and subroutine DICAP (direct capture subroutine)'
*
      RETURN
      END
**********************************************************************
*    ********    Test input of subroutine EIGEN   *******
*
*  To use the example below, delete the symbol '*' of the corresponding row
*  and copy the module to the corresponding input file.
*
*  The other comment lines should be kept.
*
*=========================================
*
* IOPT  = option for potentials: 1 (2) for Woods-Saxon (M3Y)
* NPNTS = no. of integration points in radial coordinate ( < 10000)
* RMAX  = maximum radius size (< 250 fm). 
*
* IOPT    NPTS    RMAX
*
*  1       9999    250.
*
* N_0  =  nodes of the Wave Function (exclude origin)   
* J0   =  single-particle angular momentum   
* L0   =  orbital angular momentum
*
* N_0    J_0     L_0
* 
*  0      1.5      1
*
* If IOPT = 1, enter:
* V0  =  depth of central pot. 
* VS0 =  depth of spin-orbit potential 
* R0  =  radius of the potential 
* AA  =  diffuseness of the pot. 
* RS0 =  radius of the spin-orbit pot. 
* AAS =  diffuseness of the spin-orbit pot. 
* RC  =  Coulomb radius (usually, RC = R0)  
*-----------------------------------------------------------------
*  WS =  V_0 f(r,R0,AA) - V_S0 (l.s) (r_0^2/r) d/dr f(r,RS0,AAS) 
*  
*  f(r,R0,a) = [ 1 + exp((r-R_0)/a) ]^(-1)
*
*  r_0 = 1.4138 fm is the Compton wavelength of the pion. 
*-----------------------------------------------------------------
* V0        R0       AA     VS0     RS0      AAS     RC
*
*  -44.658   2.391    0.52   -9.8    2.391    0.52    2.391 
*  -30.8   2.95    0.52   -8.53    2.95    0.52    2.95 
*
* If IOPT = 2, or else (but not 1), enter FC, FSO and RC:
*    (in this case, insert a '*' sign in above row, or delete it)
* FC      = multiplicative factor of central part of M3Y potential
* FSO     = multiplicat. factor of spin-orbit part of M3Y potential
* RC      =  Coulomb radius   
*
*  FC        FSO       RC
*   1.5       0.2       2.391
*
* Z1, Z2  =  charges of the nuclei
* A1, A2  =  masses of the nuclei (in nucleon mass units) 
*
* Z1      A1     Z2     A2
*
*   1.     1.     4.     7.  
**********************************************************************