      SUBROUTINE OMP_M3Y
*
* Calculates M3Y potential either from Fermi or Gaussian densities,
* or from densities entered in a file (DENS.INP) 
*
* Real part of the M3Y optical model potential, according to:
* G.F. Bertsch et al., Nucl. Phys. A284, 399 (1977); A.M. Kobos et 
* al., Nucl. Phys. A425, 205 (1984)
*
*   input parameters
*   ================
*
* IOPT    =  Option for densities: 0 Gaussian or Woods-Saxon
*                                  1 densities entered in DENS.INP
* NPTS    = number of integration points in radial coordinate ( < 10000)
* RMAX    = maximum radius size 
* If IOPT = 0, enter density parameters:
* R1, D1  = Woods-Saxon form (radius and diffuseness)
* R2, D2  = Same for density of nucleus 2    (for Gaussian densities, 
*           enter D1=0, or D2=0, respectively)
* A1,A2   = masses of the nuclei (in nucleon mass units) 
*
* Outputs in M3Y.TXT and OMP.INP. OMP.INP is output of "R x V(R)" 
* prepared to be used in the other subroutines.* 
*
      PARAMETER(NLG=500)
*
      IMPLICIT REAL*8(A-H,O-Z)
      REAL*8 R(0:NLG),RU(0:NLG),T(0:NLG),GINT(0:NLG),
     & DENS1(0:NLG),DENS2(0:NLG),U(0:NLG),TD2(0:NLG)         	
*
      OPEN(UNIT=12,FILE='M3Y.INP',STATUS='UNKNOWN')
      OPEN(UNIT=13,FILE='M3Y.TXT', STATUS='UNKNOWN')
*
* option for densities
      CALL SKIPCOM(12)
      READ(12,*)IOPT,NPNTS,RMAX
*
* check if we are out of bounds
      IF(NPNTS.GT.NLG .OR. RMAX.GT.30. OR. 
     &       	NPNTS.LT.100 .OR. RMAX.LT.10.) THEN
        WRITE(6,*)'THE INPUT VALUES FOR NPNTS OR RMAX ARE INADEQUATE'
        WRITE(6,*)' 100 <= NPNTS <= 500,    10 <= RMAX <= 50'
        STOP
      ENDIF
*
* density parameters
      IF (IOPT.EQ.0) THEN
        CALL SKIPCOM(12)
        READ(12,*)R1,D1,R2,D2
        CALL SKIPCOM(12)
        READ(12,*)A1,A2
      ENDIF
*
      CLOSE(UNIT=12)
*
      WRITE(13,*)'Density parameters'
      WRITE(13,*)'  R1          D1          R2          D2'  
      WRITE(13,21)R1,D1,R2,D2  
      WRITE(13,*)'Mass numbers'
      WRITE(13,*)' A1       A2'  
      WRITE(13,22)NINT(A1),NINT(A2)  
21    FORMAT(4(F8.3,4X),/)
22    FORMAT(2(I3,5X),/)
*
      WRITE(13,*)'Radial integration parameters'
      WRITE(13,*) 'NPNTS      RMAX (fm)'
      WRITE(13,8) NPNTS,RMAX
8     FORMAT(I6,4X,F8.1,/)
*
      DR = RMAX/NPNTS
      DO IR=0,NPNTS
        R(IR) = IR*DR
      END DO
*
* coefficients used in Simpson's integrations
      GINT(0)=DR/3.
      GINT(NPNTS)=DR/3.
      IG=4
      DO K=1,NPNTS-1
        GINT(K)=IG*DR/3.
        IG=6-IG
      ENDDO
*
* matter density
      IF(IOPT.EQ.1) THEN
        CALL DENS_READ(R,NPNTS,DENS1,DENS2)
        GOTO 20
      ENDIF
*
* Gaussian or WS densities
      PI = 3.14159265359
      SUM1=0.
      SUM2=0.
      DO IR=0,NPNTS
       IF(D1.NE.0.) THEN
           TEMP=(R(IR)-R1)/D1
      	 IF(TEMP.LT.30.)DENS1(IR)=1./(1.+EXP(TEMP))
         ELSE
           DENS1(IR)=EXP(-(R(IR)/R1)**2)
       ENDIF 
       IF(D2.NE.0.) THEN
           TEMP=(R(IR)-R2)/D2
      	 IF(TEMP.LT.30.)DENS2(IR)=1./(1.+EXP(TEMP))
         ELSE
           DENS2(IR)=EXP(-(R(IR)/R2)**2)
       ENDIF 
       SUM1=SUM1+GINT(IR)*4.*PI*R(IR)**2*DENS1(IR)
       SUM2=SUM2+GINT(IR)*4.*PI*R(IR)**2*DENS2(IR)
      ENDDO
*
* normalize densities
      DO IR=0,NPNTS
       DENS1(IR)=A1*DENS1(IR)/SUM1
       DENS2(IR)=A2*DENS2(IR)/SUM2
      ENDDO
*
* M3Y on a radial mesh 
20    DO IR=1,NPNTS
       S=R(IR)
       T(IR)=TM3Y(S)
      ENDDO
*
* get folding of tM3Y and dens2
      CALL TWOFOLD(R,DR,NPNTS,T,DENS1,TD2)
      C3Y=-276.
      DO IR=0,NPNTS
       TD2(IR)=TD2(IR)+C3Y*DENS1(IR)
      ENDDO
*
* fold with the other density
      CALL TWOFOLD(R,DR,NPNTS,TD2,DENS2,U)
*
* Output of the OMP
      OPEN(UNIT=71,FILE="OMP.INP",STATUS="UNKNOWN")
      WRITE(13,*)' R [fm]   x   U [MeV]'
      WRITE(71,*)NPNTS
      DO I=0,NPNTS
        WRITE(71,'(1X,F10.3,2X,G10.3))')R(I),U(I)
        WRITE(13,'(1X,F10.3,2X,G10.3))')R(I),U(I)
      END DO
      CLOSE(UNIT=71)
      CLOSE(UNIT=13)
*
      PRINT*,' '
	PRINT*,'- Output in OMP.TXT and OMP.INP'
	PRINT*,'- OMP.INP is prepared for use as input of M3Y potential' 
      PRINT*,'  by the other subroutines (if IOPT=2)'
*
      RETURN
      END
**********************************************************************
*    ********    Test input of subroutine OMP_M3Y   *******
*
*  To use the example below, delete the symbol '*' of the corresponding row
*  and copy the module to the corresponding input file.
*
*  The other comment lines should be kept.
*
*=========================================
*
* IOPT  =  Option for densities: 0 Gaussian or Woods-Saxon
*                                1 densities entered in DENS.INP
* NPNTS =  number of points in the radial mesh 
* RMAX  =  maximum radius size (fm)
*
* IOPT     NPTS    RMAX
*
*   0       100      10.
*
* If IOPT = 0, enter density parameters:
* R1, D1  =  Woods-Saxon form (radius and diffuseness)
* R2, D2  =  Same for density of nucleus 2
* For Gaussian densities, enter D1=0, or D2=0
*
* R1      D1     R2     D2
*
*  0.7     0.    1.96    0.  
*
* Mass numbers 
*
* A1      A2
*
*  1.      7.  
*
**********************************************************************